=== modified file 'Makefile'
--- Makefile	2005-12-02 05:25:53 +0000
+++ Makefile	2005-12-12 23:14:43 +0000
@@ -2,6 +2,8 @@
 
 check:
 	./bzr selftest $(tests)
+	@echo "Running all tests with no locale."
+	LC_CTYPE= LANG=C LC_ALL= ./bzr selftest $(tests)
 
 check-msgeditor:
 	./bzr --no-plugins selftest -v msgeditor

=== modified file 'NEWS'
--- NEWS	2005-12-12 05:25:59 +0000
+++ NEWS	2005-12-12 23:14:43 +0000
@@ -168,6 +168,12 @@
     * Much better error message if one of the test suites can't be 
       imported.  (Martin Pool)
 
+    * Make check now runs the test suite twice - once with the default locale,
+      and once with all locales forced to C, to expose bugs. This is not 
+      trivially done within python, so for now its only triggered by running
+      Make check. Integrators and packagers who wish to check for full 
+      platform support should run 'Make check' to test the source.
+
   INTERNALS:
 
     * WorkingTree.pull has been split across Branch and WorkingTree,

=== modified file 'bzrlib/tests/test_msgeditor.py'
--- bzrlib/tests/test_msgeditor.py	2005-12-02 05:25:53 +0000
+++ bzrlib/tests/test_msgeditor.py	2005-12-12 23:14:43 +0000
@@ -23,21 +23,18 @@
 from bzrlib.msgeditor import make_commit_message_template
 from bzrlib.tests import TestCaseInTempDir
 
-from bzrlib.tests.treeshape import build_tree_contents
-
-
-def make_uncommitted_tree():
-    """Build a branch with uncommitted changes in the cwd."""
-    b = Branch.initialize('.')
-    working_tree = b.working_tree()
-    filename = u'hell\u00d8'
-    build_tree_contents([(filename, 'contents of hello')])
-    working_tree.add(filename)
-    return working_tree
-
 
 class MsgEditorTest(TestCaseInTempDir):
 
+    def make_uncommitted_tree():
+        """Build a branch with uncommitted unicode named changes in the cwd."""
+        b = Branch.initialize('.')
+        working_tree = b.working_tree()
+        filename = u'hell\u00d8'
+        self.build_tree_contents([(filename, 'contents of hello')])
+        working_tree.add(filename)
+        return working_tree
+    
     def test_commit_template(self):
         """Test building a commit message template"""
         working_tree = make_uncommitted_tree()

=== modified file 'bzrlib/tests/test_selftest.py'
--- bzrlib/tests/test_selftest.py	2005-12-02 04:44:19 +0000
+++ bzrlib/tests/test_selftest.py	2005-12-12 23:14:43 +0000
@@ -19,7 +19,7 @@
 import os
 import sys
 
-from bzrlib.tests import TestCase, _load_module_by_name
+from bzrlib.tests import TestCase, TestCaseInTempDir, _load_module_by_name
 
 
 class SelftestTests(TestCase):
@@ -35,8 +35,17 @@
 
 
 class MetaTestLog(TestCase):
+
     def test_logging(self):
         """Test logs are captured when a test fails."""
         self.log('a test message')
         self._log_file.flush()
         self.assertContainsRe(self._get_log(), 'a test message\n')
+
+
+class TestTreeShape(TestCaseInTempDir):
+
+    def test_unicode_paths(self):
+        filename = u'hell\u00d8'
+        self.build_tree_contents([(filename, 'contents of hello')])
+        self.failUnlessExists(filename)

